/*
 * Project name:
     DIGI POT 2 click
 * Copyright:
     (c) Mikroelektronika, 2016.
  * Revision History
     20160622 (AM);
       - initial release;
 * Description:
     This program demonstrates the usage of Digital Potentiometer 2 Board (TPL0501).
     Voltage derived from W pin is read by MCU's ADC GP06 (AN1). Scaled value is then displayed at TFT.
     User can increase or decrease resitance by pressing buttons GPIO_8 and GPIO_12. It's all happening in an endless loop.
* Test configuration:
     Device:          FT900
                      http://www.ftdichip.com/Support/Documents/DataSheets/ICs/DS_FT900_1_2_3.pdf
     Dev.Board:       EasyFT90x v7 for FT900
                      http://http://www.mikroe.com/easyft90x/
     Oscillator:      CPU at full system clock, 100.000MHz
     Ext. modules:    Digi POT 2 click

     SW:              mikroC PRO for FT90x
                      http://www.mikroe.com/mikroc/ft90x/
 * NOTES:
     - Digi Pot 2 click must be connected on mikroBUS socket 1.
     - Connect DigiPot's H to Vcc, L to Gnd and W to GP06 pin.
     - Don't use pull-up(down) resistor at GP06 pin.
     - Place Button Press Level switch in upper position for 08-15
           and pull down GP08 and GP12 (Port 08-15 three-state switch).
*/

#include <built_in.h>

sbit DigPot_CS at GPIO_PIN28_bit;

// Declare global variables
unsigned int oldstate;
unsigned int adc_value;
unsigned short counter;


/**************************************************************************************************
* Init Main
**************************************************************************************************/
void InitMain() {


  GPIO_Digital_Output(&GPIO_PORT_32_39, _GPIO_PINMASK_ALL);    // Set GPIO_PORT_16_23 as digital output
  GPIO_Pin_Digital_Input(8);                                   // Set GPIO pin 8 to be input
  GPIO_Pin_Digital_Input(12);                                  // Set GPIO pin 12 to be input
  GPIO_Pin_Digital_Output(28);                                 // Set GPIO pin 28 to be input
  
  // Initialize ADC
  ADC_Init();
  ADC_Set_Input_Channel(_ADC_CHANNEL_1);

  DigPot_CS = 1;                                               // Set CS on the SPI to be HIGH

  // Initialize SPIM1 module
  SPIM1_Init_Advanced(_SPI_MASTER_CLK_RATIO_32, _SPI_CFG_POLARITY_IDLE_LOW | _SPI_CFG_PHASE_CAPTURE_FALLING, _SPI_SS_LINE_NONE);

  adc_value = 0;
  counter = 200;

}


/**************************************************************************************************
* Main Function
**************************************************************************************************/
void main() {

  InitMain();                            // Perform main initialization
  
 while(1){
  
    DigPot_CS = 0;                       // Select PotentioMeter chip
    SPIM1_Write(0);
    SPIm1_Write(counter);

    SPIM1_Write(0x20);
    SPIM1_Write(counter);
    DigPot_CS = 1;                       // Deselect PotentioMeter chip
    
  
    adc_value = ADC_Read(1);             // get ADC value from 1st channel
     
    GPIO_PORT_32_39 = adc_value;         // display adc_rd[7..0]
    
    // Detect pin 08
    if (Button(&GPIO_PORT_08_15, 0, 1, 1)){                   // detect logical one on GPIO_PIN8 pin

        oldstate = 1;
     }
    if (oldstate && Button(&GPIO_PORT_08_15, 0, 1, 0)) {      // detect one-to-zero transition on GPIO_PIN8 pin
        counter ++;
      if (counter == 255)
        counter = 127;
        oldstate = 0;
    }
    // Detect pin 12
    if (Button(&GPIO_PORT_08_15, 4, 1, 1)){                   // detect logical one on GPIO_PIN12 pin

        oldstate = 1;
     }
    if (oldstate && Button(&GPIO_PORT_08_15, 4, 1, 0)) {      // detect one-to-zero transition on GPIO_PIN12 pin
        counter --;
      if (counter == 127)
        counter = 255;
        oldstate = 0;
    }
    
    Delay_ms(50);                                             // delay 50ms
  }
}